@@ -1,20 +1,33 @@
 
 idesc_set_dep <- function(self, private, package, type, version) {
-  assert_that(is_string(package), is_string(version))
+  stopifnot(is_string(package), is_string(version))
   deps <- self$get_deps()
   has <- which(deps$package == package & deps$type == type)
 
   if (length(has)) {
     deps[ has, "version" ] <- version
-
   } else {
-    deps <- rbind(
-      deps,
-      data.frame(
-        stringsAsFactors = FALSE,
-        type = type, package = package, version = version
-      )
+    row <- data.frame(
+      stringsAsFactors = FALSE,
+      type = type, package = package, version = version
     )
+    others <- deps$package[deps$type == type]
+    sorted <- !is.unsorted(tolower(others)) && length(others) > 0
+
+    if (sorted) {
+      # find first row it should come after
+      idx <- which(deps$type == type & tolower(package) > tolower(deps$package))
+      if (length(idx) == 0) {
+        # must be first
+        idx <- which(deps$type == type)[[1]]
+      } else {
+        idx <- length(idx) + 1
+      }
+    } else {
+      idx <- nrow(deps) + 1
+    }
+
+    deps <- insert_row(deps, row, where = idx)
   }
 
   idesc_set_deps(self, private, deps)
@@ -22,7 +35,7 @@ idesc_set_dep <- function(self, private, package, type, version) {
 
 
 idesc_set_deps <- function(self, private, deps) {
-  assert_that(is_deps_df(deps))
+  stopifnot(is_deps_df(deps))
   depdeps <- deparse_deps(deps)
   for (d in names(depdeps)) {
     if (! same_deps(depdeps[[d]], private$data[[d]]$value)) {
@@ -51,12 +64,31 @@ same_deps <- function(d1, d2) {
     all(d1$version == d2$version)
 }
 
+#' Get dependencies
+#'
+#' In case the package has no dependencies at all, we `rbind` the
+#' list of data frames with the various dependency types, with an
+#' empty data frame. This ensures that we don't get `NULL` for the edge
+#' case, but a nice data frame with zero rows.
+#'
+#' @param self self
+#' @param private private self
+#' @return data frame of dependencies
+#'
+#' @keywords internal
+#' @noRd
 
 idesc_get_deps <- function(self, private) {
   types <- intersect(names(private$data), dep_types)
   res <- lapply(types, function(type)
     parse_deps(type, private$data[[type]]$value))
-  do.call(rbind, res)
+  empty <- data.frame(
+    stringsAsFactors = FALSE,
+    type = character(),
+    package = character(),
+    version = character()
+  )
+  do.call(rbind, c(list(empty), res))
 }
 
 
@@ -70,7 +102,8 @@ parse_deps <- function(type, deps) {
     package = vapply(deps, "[", "", 1),
     version = vapply(deps, "[", "", 2)
   )
-  res [ is.na(res) ] <- "*"
+  res$version <- gsub("\\s+", " ", res$version)
+  res$version [ is.na(res$version) ] <- "*"
   res
 }
 
@@ -93,7 +126,7 @@ deparse_deps <- function(deps) {
 
 
 idesc_del_dep <- function(self, private, package, type) {
-  assert_that(is_string(package))
+  stopifnot(is_string(package))
   deps <- self$get_deps()
 
   if (type == "all") {
@@ -118,14 +151,25 @@ idesc_del_deps <- function(self, private) {
 
 
 idesc_has_dep <- function(self, private, package, type) {
-  assert_that(is_string(package))
+  stopifnot(is_string(package))
 
   deps <- self$get_deps()
   if (type == "any") {
     package %in% deps$package
 
   } else {
-    package %in% deps$package &&
-      type %in% deps[match(package, deps$package), "type"]
+    any(deps$package == package & deps$type == type)
   }
 }
+
+insert_row <- function(x, y, where = 1L) {
+  if (where == 1L) {
+    rbind(y, x)
+  } else if (where > nrow(x)) {
+    rbind(x, y)
+  } else {
+    top <- 1:(where - 1)
+    rbind(x[top, , drop = FALSE], y, x[-top, , drop = FALSE])
+  }
+}
+
